from fastapi import FastAPI, Request, responses, templating


class DocumentationRoute:
    @staticmethod
    def init_documentation(app: FastAPI, file_name: str, templates: templating.Jinja2Templates):
        @app.get('/', response_class=responses.HTMLResponse, include_in_schema=False)
        async def root(request: Request):
            urls = {
                'Docs': f'{request.base_url}docs',
                'Redoc': f'{request.base_url}redoc',
            }

            return templates.TemplateResponse(
                name=file_name,
                context={
                    'request': request,
                    'urls': urls,
                    'title': getattr(app, 'title'),
                },
            )



from edgegap_database import DatabaseOperator
from sqlmodel import Session, select

from ._interface import CheckInterface
from ._model import CheckInstanceModel


class DatabaseCheck(CheckInterface):
    __name__ = 'Database'

    def _check(self, **kwargs) -> CheckInstanceModel:
        ok = False
        message = 'No Session Supplied to Database Check'

        session = kwargs.get('session')

        if isinstance(session, Session):
            try:
                operator = DatabaseOperator(session)
                operator.exec(select(True))
                ok = True
                message = 'ok'
            except Exception as e:
                message = str(e)

        return CheckInstanceModel(ok=ok, message=message)



from pydantic import BaseModel, Field


class CheckInstanceModel(BaseModel):
    ok: bool = Field(default=True, description='If the Check is OK')
    message: str = Field(default='ok', description='The message of the Check')


class CheckModel(CheckInstanceModel):
    name: str = Field(..., description='The name of the Check')



from edgegap_settings import EnvironmentField
from pydantic_settings import BaseSettings


class EnvironmentConfiguration(BaseSettings):
    log_level: str = EnvironmentField(
        key='LOG_LEVEL',
        description='The logging Level',
        default='DEBUG',
    )

    log_format: str = EnvironmentField(
        key='LOG_FORMAT',
        description='The Logging Format',
        default='%(asctime)s | %(levelname)s | %(name)s | %(message)s',
    )

    log_access_format: str = EnvironmentField(
        key='LOG_ACCESS_FORMAT',
        description='The Logging Format for API Access',
        default='%(asctime)s | %(levelname)s | %(name)s | %(client_addr)s - [%(request_line)s] %(status_code)s',
    )
